@@ -457,142 +457,6 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
         return False
 
 
-@celery.shared_task(bind=True, ignore_result=True)
-def chunk_import_file(self, importqueue_pk, insert_size=5, slice_size=1000):
-    """Imports a file with a tangled web of task distribution in order to effect parallelization.
-    """
-    
-    load = ImportQueue.objects.get(pk=importqueue_pk)
-    load.status = 'RECEIVED'
-    load.celery_task_id = self.request.id
-    load.save()
-    
-    logger.info('Received for import with celery task chunking: %s' % (load))
-    
-    destination = load.batch.destination
-    
-    # proceed with making the file happen
-    load.status = 'IN PROCESS'
-    load.start = datetime.datetime.utcnow().replace(tzinfo=utc)
-    load.save()
-    
-    logger.info('Begin import: %s' % (load))
-    
-    cols_saved = load.record_columns()
-    if cols_saved > 0:
-        logger.info('Columns saved: %s for %s' % (cols_saved, load))
-    else:
-        logger.info('No columns saved for %s' % (load))
-    
-    table = destination.name
-    schema = destination.schema
-    state = load.file.state.abbreviation
-    year = load.file.year
-    dsabbr = destination.source.abbreviation
-    
-    handle = load.file.open()
-    meta = load.get_meta()
-    
-    # make a generator to yield one slice_size slice of the file in question at a time
-    reader = pyhcup.parser.read(handle, meta, chunksize=slice_size)
-
-    # take 5
-    # loop through slices and dispatch chunker.chunks() for each
-    # this is preferred to a chain so that it doesn't wait to start until after all the signatures are generated
-    result_lst = []
-    for df in reader:
-        # everything we insert will always have a state and year associated with it
-        # if they aren't already in the frame, add them from the passed values
-        # (which should in turn be from the loadfile object)
-        if 'state' not in df.columns.map(lambda x: str(x).lower()):
-            df['state'] = state
-        
-        if 'year' not in df.columns.map(lambda x: str(x).lower()):
-            df['year'] = year
-        
-        cleaned_df = replace_sentinels(df)
-        
-        if dsabbr == 'CHGS' and not meta_is_long(meta):
-            # this is a wide charges file
-            # convert before chunking it out
-            cleaned_df = df_wtl(cleaned_df, category='CHGS')
-        
-        result_lst.append(chunker(
-                cleaned_df,
-                table,
-                schema,
-                insert_size
-                )
-            )
-    
-    import_complete.apply_async((result_lst, load.pk), countdown=10)
-    return True
-
-
-@celery.shared_task
-def chunker(df_slice, table, schema, insert_size=5):
-    """These should be slices far too large to build a SQL string on; e.g. >100"""
-    
-    r = xrange(0, len(df_slice), insert_size)
-    
-    # build chunks of insert jobs and turn it into a group
-    job = chunk_insert.chunks(
-        zip(
-            (df_slice[x:x+insert_size] for x in r),
-            (table for x in r),
-            (schema for x in r)
-            ),
-        10
-        ).group()
-    
-    return job.delay() # gives back an async resultgroup object
-    # for which .ready() will be True if all tasks have completed
-    # and for which .successful() will be True if all tasks were successfully completed
-
-
-@celery.shared_task
-@tx.atomic # turn off autocommit
-def chunk_insert(df_chunk, table, schema, placeholder_representation="%s"):    
-    cursor = cnxns[HACHOIR_DB_ENTRY].cursor()
-    
-    #df_chunk = replace_sentinels(df_chunk)
-    
-    try:
-        #print "df_chunk is %s" % df_chunk
-        #print "table is %s" % table
-        #print "schema is %s" % schema
-        #print "placeholder is %s" % placeholder_representation
-        insert_sql, values = gen_insert_sql(df_chunk, table, schema=schema, placeholder=placeholder_representation)    
-        logger.debug('Generated sql and values lists (params)')
-    except:
-        e = sys.exc_info()[0]
-        logger.warning('Failed to generate SQL insert statement and parameters list using pyhcup.db.insert_sql(). Raised %s.' % e)
-        #logger.warning('df_chunk is %s' % df_chunk)
-        #logger.warning('table is %s' % table)
-        #logger.warning('schema is %s' % schema)
-        #logger.warning('placeholder is %s' % placeholder_representation)
-        return False
-    
-    
-    try:
-        cursor.execute(insert_sql, values)
-        logger.debug('Executed sql using params')
-    except:
-        e = sys.exc_info()[0]
-        logger.warning('Failed to execute SQL insert statement and parameters list using cursor.execute(). Raised %s.' % e)
-        #logger.warning('insert_sql is %s' % insert_sql)
-        #logger.warning('values is %s' % values)
-        
-    
-    tx.commit(using=HACHOIR_DB_ENTRY)
-    #logger.debug('Committed transaction')
-    
-    # Do not hold a copy of the query.
-    djangodb.reset_queries()
-    #logger.debug('Inserted chunk successfully from state-year %s-%s to table %s' % (state, year, table))
-    return cursor.rowcount
-
-
 @celery.shared_task(bind=True, max_retries=None, default_retry_delay=10)
 def import_complete(self, result_lst, importqueue_pk):
     """Checks periodically to see if these have completed and updates associated ImportQueue obj with outcome
@@ -646,52 +510,6 @@ def batch_complete(self, batch_pk):
         raise self.retry(exc=Exception('Batch not yet complete: %s' % b))
 
 
-@celery.shared_task(bind=True, ignore_result=True)
-def pg_shovel_ab(self, stg_pk, destination='stg_sid_core_partprocessed'):
-    """Shovels everything from StagingTable with pk stg_pk into table named destination
-    """
-    
-    stg = StagingTable.objects.get(pk=stg_pk)
-    table_name = stg.name.lower()
-    rel_file_obj = stg.imported_via.file
-    state_abbr = rel_file_obj.state.abbreviation
-    year = rel_file_obj.year
-    
-     # establish connection directly with psycopg2
-    cnxn = get_pgcnxn()
-    
-    # generate a cursor
-    cursor = cnxn.cursor()
-    
-    # get helper function pg_shovel
-    from pyhcup.db import pg_shovel
-    
-    # get column names
-    col_sql = """
-    SELECT column_name
-    FROM information_schema.columns
-    WHERE table_name   = %s
-    """
-    #print col_sql, table_name
-    
-    
-    cursor.execute(col_sql, [table_name])
-    result = cursor.fetchall()
-    cols = [x[0] for x in result if x[0] not in ['state', 'year']]
-    #print cols
-    scalars = {
-        'state': state_abbr,
-        'year': year
-    }
-    #print scalars
-    
-    shoveled = pg_shovel(cnxn, table_name, destination, fields_in=cols, scalars=scalars)
-    
-    logger.info('Shoveled %s rows' % shoveled)
-
-    return True
-
-
 @celery.shared_task(bind=True, ignore_result=True)
 def pg_stage(self, stagingqueue_pk):
     """Processes StagingQueue object with primary key stagingqueue_pk. Automatically creates and records destination table as appropriate.
@@ -1069,12 +887,17 @@ def pg_stage(self, stagingqueue_pk):
         staged.records = affected_rows
         staged.wip = False
         staged.save()
+        stg_q.success('StagingTable %s (pk %s) updated as non-WIP and %s rows' % (staged.name, staged.pk, staged.records))
         
         # save a reference to the StagingTable in the StagingQueue object as output
         stg_q.stg_output = staged
         stg_q.save()
-        stg_q.success('StagingTable %s (pk %s) updated as non-WIP and %s rows' % (staged.name, staged.pk, staged.records))
+        stg_q.success('StagingTable {tbl} (pk {tbl_pk}) saved as stg_output for StagingQueue object {stg}' \
+            .format(tbl=staged.name, tbl_pk=staged.pk, stg=stg_q.pk))
 
+        stg_q.success('Seeking deprecated StagingTable objects to mark as void (looking for category {cat}, state {st}, year {yr}, with pk NOT {pk}' \
+            .format(cat=staged.category, st=staged.state, yr=staged.year, pk=staged.pk))
+        
         return True
 
 
