@@ -305,109 +305,21 @@ def run_batch(request, obj_id, obj_type):
             .format(t=obj_type, a=ALLOWED_BATCH_TYPES))
     
     if obj_type == 'ImportBatch':
-        logger.info('Attempting to call a Celery task for importing batch_id %i' % (int(batch_id)))
-        tresult = tasks.batch_import.delay(batch_id)
+        logger.info('Attempting to call a Celery task for ImportBatch %i' % (int(obj_id)))
+        tresult = tasks.batch_import.delay(obj_id)
         response = "ImportBatch has been dispatched to Celery in thread %s." % (tresult)
         logger.info(response)
         return obj_detail(request, obj_id, obj_type, msg_pt=[response])
     
     elif obj_type == 'StagingBatch':
-        logger.info('Attempting to call a Celery task for StagingBatch %i' % (int(batch_id)))
-        tresult = tasks.batch_stage.delay(batch_id)
+        logger.info('Attempting to call a Celery task for StagingBatch %i' % (int(obj_id)))
+        tresult = tasks.batch_stage.delay(obj_id)
         response = "StagingBatch has been dispatched to Celery in thread %s." % (tresult)
         logger.info(response)
         return obj_detail(request, obj_id, obj_type, msg_pt=[response])
 
 
-def src_gen_master_table(request, source_id):
-    """For wide data, use all known loadfiles for source and generate one master table. For long data (or data which can be longed), make the corresponding fixed-style table.
-    """
-    
-    source = DataSource.objects.get(pk=source_id)
-    logger.info('Attempting to generate master table for %s' % source)
-    
-    cursor = cnxns[DJHCUP_DB_ENTRY].cursor()
 
-    # need later for table creation, but want the value to be based on the start of the process
-    now = datetime.datetime.utcnow().replace(tzinfo=utc).strftime("%Y%m%d%H%M%S")
-    db_table = "%s_%s" % (source.mr_descriptor, now)
-    pk_fields = []
-    index_fields = []
-    
-    # check to see whether this source has a LONG_MAPS entry, which would indicate it ought to be a long table
-    from pyhcup.parser import LONG_MAPS
-    if source.abbreviation in LONG_MAPS.keys():
-        logger.info('Match found in LONG_MAPS. This should be a fixed-style long table.')
-        create_sql = pyhcup.db.long_table_sql(db_table, str(source.abbreviation))
-        index_fields = ['KEY', 'VISITLINK', 'STATE', 'YEAR']
-    
-    else:
-        logger.info('No match found in LONG_MAPS. This should be a dynamically-generated wide table.')
-        
-        src_loadfiles = File.objects.filter(file_type__content_type__in=['LOAD'], file_type__source=source)
-        logger.info('Found %d loadfile records matching source' % len(src_loadfiles))
-        
-        meta_list = []
-        excluded = []
-        for lf in src_loadfiles:
-            try:
-                if lf.state.abbreviation.lower() == 'tx':
-                    # read the meta using the tx pudf stuff
-                    mdf = pyhcup.tx.meta_from_txt(lf.full_path)
-                    # mdf['state'] = 'tx'
-                    # mdf['year']
-                    augmented = pyhcup.meta.augment(mdf, dialect='pudf')
-                
-                else:
-                    # read the meta using the sas stuff
-                    mdf = pyhcup.sas.meta_from_sas(lf.full_path)
-                    augmented = pyhcup.meta.augment(mdf)
-                
-                # in any case, put in the meta list collection
-                meta_list.append(augmented)
-                
-            except:
-                # failed to read these in for some reason; held here for debug
-                excluded.append(lf.full_path)
-        
-        merged_meta = pyhcup.meta.merge(meta_list)
-        logger.info('Merged %d meta DataFrames successfully, with %d columns after de-duplication' % (len(meta_list), len(merged_meta)))
-        
-        constraints = ['NULL']
-        if source.top_level_source.abbreviation == 'HCUP':# redundant # and source.abbreviation not in LONG_MAPS.keys():
-            pk_fields = ['year', 'state', 'key']
-            index_fields += pk_fields
-        
-        create_sql = pyhcup.db.table_sql(merged_meta, db_table, pk_fields=pk_fields, ine=True, append_state=True, default_constraints=constraints)
-        
-    try:
-        cursor.execute(create_sql)
-        tx.commit(using=DJHCUP_DB_ENTRY)
-    except:
-        e = sys.exc_info()[0]
-        raise Exception("Failed to create master table with query %s (%s)" % (create_sql, e))
-    
-    logger.info('Created master table %s with on database %s' % (db_table, DJHCUP_DB_ENTRY))
-    
-    if index_fields != None:
-        try:
-            for col in index_fields:
-                index = pyhcup.db.index_sql(col, db_table)
-                cursor.execute(index)
-                tx.commit(using=DJHCUP_DB_ENTRY)
-                logger.info('Created index for column %s with on table %s' % (col, db_table))
-        except:
-            raise Exception("Failed to create indexes on table, particularly one that should have resulted from this query: %s" % index)
-    
-    table_record = StagingTable(source=source, name=db_table, database=DJHCUP_DB_ENTRY)
-    table_record.save()
-    logger.info('Saved master table details as StagingTable record %d' % table_record.pk)
-    
-    context = {
-        'title': 'Generate Master Table',
-        }
-    template = 'stg_base.html'
-    return render(request, template, context)
 
 
 def create_batch_from_unimported(request):
@@ -419,7 +331,7 @@ def create_batch_from_unimported(request):
     return importbatch_inventory(request, msg_pass_through=[message])
 
 
-def create_batch_from_unprocessed(request):
+def batch_from_unprocessed(request):
     batches = staging.unprocessed_batches()
     
     messages = [
@@ -428,7 +340,8 @@ def create_batch_from_unprocessed(request):
         for b in batches
     ]
     
-    return importbatch_inventory(request, msg_pass_through=messages)
+    return obj_detail(request, obj_id=b.pk, obj_type="StagingBatch", msg_pt=messages)
+    #return importbatch_inventory(request, msg_pass_through=messages)
 
 
 def batch_reset_dead(request):
